@@ -25,11 +25,104 @@
 
 
 #ifdef __IOTK_INTEGER3
-#if 3 <= __IOTK_MAXRANK
+#if 0 <= __IOTK_MAXRANK
 
+! This is needed as a workaround for bugged pack 
+subroutine iotk_private_pack_INTEGER3(out,in,n,l)
+    use iotk_base
+    implicit none
+    integer,                                    intent(in)  :: n,l
+    INTEGER (kind=iotk_INTEGER3), intent(out) :: out(n)
+    INTEGER (kind=iotk_INTEGER3), intent(in)  :: in(n)
+    out = in
+end subroutine iotk_private_pack_INTEGER3
 
+subroutine iotk_write_INTEGER3(val,string,fmt,ierr)
+  use iotk_base
+  use iotk_error_interf
+  use iotk_xtox_interf
+  use iotk_fmt_interf
+  use iotk_str_interf
+  use iotk_misc_interf
+  implicit none
+  INTEGER(kind=iotk_INTEGER3), intent(in) :: val(:)
+#ifdef __IOTK_WORKAROUND6
+  character(len=*)              :: string
+#else
+  character(len=*), intent(out) :: string
+#endif
+  character(len=*), intent(in)  :: fmt
+  integer, intent(out) :: ierr
+  integer :: index,iostat
+  ierr = 0
+  iostat = 0 
+  string(1:1) = iotk_eos
+  if(size(val)==0) return
+  if(len(string)==0) then
+    call iotk_error_issue(ierr,"iotk_write",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.21 ")
+    return
+  end if
+  do index=1,size(val)
+    call iotk_strcat(string,trim(iotk_itoa(val(index)))//" ",ierr)
+    if(ierr/=0) then
+      call iotk_error_issue(ierr,"iotk_write",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.21 ")
+      return
+    end if
+  end do
+! the last blank is deleted
+  string(iotk_strlen(string):iotk_strlen(string)) = iotk_eos
+end subroutine iotk_write_INTEGER3
 
-subroutine iotk_write_attr_INTEGER3_3(attr,name,val,dummy,first,newline,fmt,ierr)
+subroutine iotk_read_INTEGER3(val,string,index,ierr)
+  use iotk_base
+  use iotk_error_interf
+  use iotk_xtox_interf
+  use iotk_misc_interf
+  implicit none
+  INTEGER(kind=iotk_INTEGER3), intent(inout) :: val(:)
+  character(len=*), intent(in) :: string
+  integer, intent(inout) :: index
+  integer, intent(out) :: ierr
+  logical :: check
+  integer :: pos,pos1,iostat
+  integer :: maxindex
+#ifdef __IOTK_WORKAROUND9
+  character(len=100) :: tmpstr ! debug
+#endif
+  pos = 0
+  pos1= 0
+  ierr = 0
+  iostat = 0
+    maxindex = size(val)
+! for the moment, commas are considered as blanks
+  do
+    pos = verify(string(pos1+1:)," ,")+pos1
+    if(pos==pos1) exit
+    pos = pos - 1
+    pos1 = scan(string(pos+1:)," ,")+pos
+    if(pos1==pos) pos1 = len(string) + 1
+!READ string(pos+1:pos1-1)
+    index = index+1
+    if(index>maxindex) then
+      call iotk_error_issue(ierr,"iotk_read",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.21 ")
+call iotk_error_msg(ierr,'Too many data')
+    end if
+    call iotk_atoi(val(index),string(pos+1:pos1-1),check=check)
+    if(.not.check) then
+      call iotk_error_issue(ierr,"iotk_read",__FILE__,__LINE__)
+call iotk_error_msg(ierr,"CVS Revision: 1.21 ")
+call iotk_error_msg(ierr,'Wrong string')
+call iotk_error_write(ierr,"string",string(pos+1:pos1-1))
+      return
+    end if
+    if(pos1>=len(string)) exit
+  end do
+end subroutine iotk_read_INTEGER3
+
+subroutine iotk_write_attr_INTEGER3_0(attr,name,val,dummy,first,newline,fmt,ierr)
   use iotk_base
   use iotk_error_interf
   use iotk_attr_interf
@@ -38,7 +131,7 @@ subroutine iotk_write_attr_INTEGER3_3(attr,name,val,dummy,first,newline,fmt,ierr
   implicit none
   character(*), intent(inout) :: attr
   character(*), intent(in)    :: name
-  INTEGER(kind=iotk_INTEGER3), intent(in)  :: val (:,:,:)
+  INTEGER(kind=iotk_INTEGER3), intent(in)  :: val 
   type(iotk_dummytype), optional :: dummy
   logical, optional, intent(in)  :: first
   logical, optional, intent(in)  :: newline
@@ -78,7 +171,7 @@ call iotk_error_write(ierrl,"name",name(1:namlen))
     goto 1
   end if
   delim = '"'
-  call iotk_write(pack(val,mask=.true.),tmpval,usefmt,ierrl)
+  call iotk_write((/val/),tmpval,usefmt,ierrl)
   if(ierrl/=0) then
     call iotk_error_issue(ierrl,"iotk_write_attr",__FILE__,__LINE__)
 call iotk_error_msg(ierrl,"CVS Revision: 1.21 ")
@@ -103,9 +196,9 @@ call iotk_error_msg(ierrl,'Attribute dummy argument is too short')
   else
     if(ierrl/=0) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_write_attr_INTEGER3_3
+end subroutine iotk_write_attr_INTEGER3_0
 
-subroutine iotk_scan_attr_INTEGER3_3(attr,name,val,dummy,found,default,eos,ierr)
+subroutine iotk_scan_attr_INTEGER3_0(attr,name,val,dummy,found,default,eos,ierr)
   use iotk_base
   use iotk_error_interf
   use iotk_attr_interf, only : iotk_read
@@ -115,13 +208,13 @@ subroutine iotk_scan_attr_INTEGER3_3(attr,name,val,dummy,found,default,eos,ierr)
   character(*),             intent(in)  :: attr
   character(*),             intent(in)  :: name
 #ifdef __IOTK_WORKAROUND6
-  INTEGER(kind=iotk_INTEGER3)                        :: val (:,:,:)
+  INTEGER(kind=iotk_INTEGER3)                        :: val 
 #else
-  INTEGER(kind=iotk_INTEGER3), intent(out)           :: val (:,:,:)
+  INTEGER(kind=iotk_INTEGER3), intent(out)           :: val 
 #endif
   type(iotk_dummytype), optional :: dummy
   logical,        optional, intent(out) :: found
-  INTEGER(kind=iotk_INTEGER3), optional, intent(in)  :: default (:,:,:)
+  INTEGER(kind=iotk_INTEGER3), optional, intent(in)  :: default 
   logical,        optional, intent(in)  :: eos
   integer,        optional, intent(out) :: ierr
   integer :: ierrl
@@ -182,7 +275,7 @@ call iotk_error_msg(ierrl,"CVS Revision: 1.21 ")
   else
     goto 1
   end if
-  allocate(tmpval(size(val)))
+  allocate(tmpval(1))
   index = 0
   call iotk_str_clean(valc)
   call iotk_read(tmpval,valc(1:iotk_strlen(valc)),index,ierrl)
@@ -191,7 +284,7 @@ call iotk_error_msg(ierrl,"CVS Revision: 1.21 ")
 call iotk_error_msg(ierrl,"CVS Revision: 1.21 ")
     goto 1
   end if
-  if(index/=size(val)) then
+  if(index/=1) then
     call iotk_error_issue(ierrl,"iotk_scan_attr",__FILE__,__LINE__)
 call iotk_error_msg(ierrl,"CVS Revision: 1.21 ")
 call iotk_error_msg(ierrl,'Attribute size does not match')
@@ -199,7 +292,7 @@ call iotk_error_write(ierrl,"attr",valc)
 call iotk_error_write(ierrl,"size",size(tmpval))
     goto 1
   end if
-  val = reshape (source=tmpval,shape=shape(val))
+  val = tmpval(1)
   deallocate(tmpval)
 1 continue
   if(ierrl/=0) foundl=.false.
@@ -219,14 +312,14 @@ call iotk_error_write(ierrl,"name",name)
   else
     if(ierrl/=0) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_scan_attr_INTEGER3_3
+end subroutine iotk_scan_attr_INTEGER3_0
 
 #endif
 #endif
 
-subroutine iotk_attr_dummy_INTEGER3_3
+subroutine iotk_attr_dummy_INTEGER3_0
   write(0,*)
-end subroutine iotk_attr_dummy_INTEGER3_3
+end subroutine iotk_attr_dummy_INTEGER3_0
 
 
 
@@ -240,11 +333,11 @@ end subroutine iotk_attr_dummy_INTEGER3_3
 
 
 #ifdef __IOTK_INTEGER3
-#if 4 <= __IOTK_MAXRANK
+#if 1 <= __IOTK_MAXRANK
 
 
 
-subroutine iotk_write_attr_INTEGER3_4(attr,name,val,dummy,first,newline,fmt,ierr)
+subroutine iotk_write_attr_INTEGER3_1(attr,name,val,dummy,first,newline,fmt,ierr)
   use iotk_base
   use iotk_error_interf
   use iotk_attr_interf
@@ -253,7 +346,7 @@ subroutine iotk_write_attr_INTEGER3_4(attr,name,val,dummy,first,newline,fmt,ierr
   implicit none
   character(*), intent(inout) :: attr
   character(*), intent(in)    :: name
-  INTEGER(kind=iotk_INTEGER3), intent(in)  :: val (:,:,:,:)
+  INTEGER(kind=iotk_INTEGER3), intent(in)  :: val (:)
   type(iotk_dummytype), optional :: dummy
   logical, optional, intent(in)  :: first
   logical, optional, intent(in)  :: newline
@@ -318,9 +411,9 @@ call iotk_error_msg(ierrl,'Attribute dummy argument is too short')
   else
     if(ierrl/=0) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_write_attr_INTEGER3_4
+end subroutine iotk_write_attr_INTEGER3_1
 
-subroutine iotk_scan_attr_INTEGER3_4(attr,name,val,dummy,found,default,eos,ierr)
+subroutine iotk_scan_attr_INTEGER3_1(attr,name,val,dummy,found,default,eos,ierr)
   use iotk_base
   use iotk_error_interf
   use iotk_attr_interf, only : iotk_read
@@ -330,13 +423,13 @@ subroutine iotk_scan_attr_INTEGER3_4(attr,name,val,dummy,found,default,eos,ierr)
   character(*),             intent(in)  :: attr
   character(*),             intent(in)  :: name
 #ifdef __IOTK_WORKAROUND6
-  INTEGER(kind=iotk_INTEGER3)                        :: val (:,:,:,:)
+  INTEGER(kind=iotk_INTEGER3)                        :: val (:)
 #else
-  INTEGER(kind=iotk_INTEGER3), intent(out)           :: val (:,:,:,:)
+  INTEGER(kind=iotk_INTEGER3), intent(out)           :: val (:)
 #endif
   type(iotk_dummytype), optional :: dummy
   logical,        optional, intent(out) :: found
-  INTEGER(kind=iotk_INTEGER3), optional, intent(in)  :: default (:,:,:,:)
+  INTEGER(kind=iotk_INTEGER3), optional, intent(in)  :: default (:)
   logical,        optional, intent(in)  :: eos
   integer,        optional, intent(out) :: ierr
   integer :: ierrl
@@ -434,14 +527,14 @@ call iotk_error_write(ierrl,"name",name)
   else
     if(ierrl/=0) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_scan_attr_INTEGER3_4
+end subroutine iotk_scan_attr_INTEGER3_1
 
 #endif
 #endif
 
-subroutine iotk_attr_dummy_INTEGER3_4
+subroutine iotk_attr_dummy_INTEGER3_1
   write(0,*)
-end subroutine iotk_attr_dummy_INTEGER3_4
+end subroutine iotk_attr_dummy_INTEGER3_1
 
 
 
@@ -455,11 +548,11 @@ end subroutine iotk_attr_dummy_INTEGER3_4
 
 
 #ifdef __IOTK_INTEGER3
-#if 5 <= __IOTK_MAXRANK
+#if 2 <= __IOTK_MAXRANK
 
 
 
-subroutine iotk_write_attr_INTEGER3_5(attr,name,val,dummy,first,newline,fmt,ierr)
+subroutine iotk_write_attr_INTEGER3_2(attr,name,val,dummy,first,newline,fmt,ierr)
   use iotk_base
   use iotk_error_interf
   use iotk_attr_interf
@@ -468,7 +561,7 @@ subroutine iotk_write_attr_INTEGER3_5(attr,name,val,dummy,first,newline,fmt,ierr
   implicit none
   character(*), intent(inout) :: attr
   character(*), intent(in)    :: name
-  INTEGER(kind=iotk_INTEGER3), intent(in)  :: val (:,:,:,:,:)
+  INTEGER(kind=iotk_INTEGER3), intent(in)  :: val (:,:)
   type(iotk_dummytype), optional :: dummy
   logical, optional, intent(in)  :: first
   logical, optional, intent(in)  :: newline
@@ -533,9 +626,9 @@ call iotk_error_msg(ierrl,'Attribute dummy argument is too short')
   else
     if(ierrl/=0) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_write_attr_INTEGER3_5
+end subroutine iotk_write_attr_INTEGER3_2
 
-subroutine iotk_scan_attr_INTEGER3_5(attr,name,val,dummy,found,default,eos,ierr)
+subroutine iotk_scan_attr_INTEGER3_2(attr,name,val,dummy,found,default,eos,ierr)
   use iotk_base
   use iotk_error_interf
   use iotk_attr_interf, only : iotk_read
@@ -545,13 +638,13 @@ subroutine iotk_scan_attr_INTEGER3_5(attr,name,val,dummy,found,default,eos,ierr)
   character(*),             intent(in)  :: attr
   character(*),             intent(in)  :: name
 #ifdef __IOTK_WORKAROUND6
-  INTEGER(kind=iotk_INTEGER3)                        :: val (:,:,:,:,:)
+  INTEGER(kind=iotk_INTEGER3)                        :: val (:,:)
 #else
-  INTEGER(kind=iotk_INTEGER3), intent(out)           :: val (:,:,:,:,:)
+  INTEGER(kind=iotk_INTEGER3), intent(out)           :: val (:,:)
 #endif
   type(iotk_dummytype), optional :: dummy
   logical,        optional, intent(out) :: found
-  INTEGER(kind=iotk_INTEGER3), optional, intent(in)  :: default (:,:,:,:,:)
+  INTEGER(kind=iotk_INTEGER3), optional, intent(in)  :: default (:,:)
   logical,        optional, intent(in)  :: eos
   integer,        optional, intent(out) :: ierr
   integer :: ierrl
@@ -649,13 +742,13 @@ call iotk_error_write(ierrl,"name",name)
   else
     if(ierrl/=0) call iotk_error_handler(ierrl)
   end if
-end subroutine iotk_scan_attr_INTEGER3_5
+end subroutine iotk_scan_attr_INTEGER3_2
 
 #endif
 #endif
 
-subroutine iotk_attr_dummy_INTEGER3_5
+subroutine iotk_attr_dummy_INTEGER3_2
   write(0,*)
-end subroutine iotk_attr_dummy_INTEGER3_5
+end subroutine iotk_attr_dummy_INTEGER3_2
 
 
