@@ -1,20 +1,15 @@
 #!/bin/bash
 # PATCH SCRIPT FOR LAMMPS 
 #
-# USER DEFINED ARCHITECTURE:
-# this is strictly dependent on the arch 
-#
-myarch="openmpi"
-
 # this script needs to be launched from the src directory in lammps 
 #
 #
 destination="$PWD/src"
 
 # definitions specific to this code
-CODE="lammps_8-12-2009"
+CODE="lammps_15-01-2010"
 LINKED_FILES="$plumedir/common_files/*.h $plumedir/common_files/*.c"
-WHERE_LINKS="."
+WHERE_LINKS="./USER-PLUMED"
 
 # this changes the names from .c to .C
 PLUMED_RENAME_RULE=plumed_rename_rule
@@ -27,70 +22,184 @@ function plumed_rename_rule (){
 
 function to_do_before_patch () {
   echo > /dev/null
+  mkdir ${destination}/USER-PLUMED
 }
 
 function to_do_after_patch () {
 #
 # after creating links and patches
 #
-cd src
-mkdir ./USER-PLUMED
-cat > ./USER-PLUMED/Install.sh << \EOF
+cd USER-PLUMED
+cat > ./Install.sh << \EOF
 # Install/unInstall package classes in LAMMPS
 
 if (test $1 = 1) then
 
-  cp -p style_user_plumed.h ..
-
-  cp -p fix_plumed.cpp ..
-
-  cp -p fix_plumed.h ..
+  cp -p style_user_plumed.h ../
+  cp -p metadyn.h ../
+  cp -p fix_plumed.h ../
+  cp -p testderivatives.cpp ../
+  cp -p restraint_zpath.cpp ../
+  cp -p restraint_waterbridge.cpp ../
+  cp -p restraint_torsion.cpp ../
+  cp -p restraint_spath.cpp ../
+  cp -p restraint_rmsdtor.cpp ../
+  cp -p restraint_rgyr.cpp ../
+  cp -p restraint_puckering.cpp ../
+  cp -p restraint_position.cpp ../
+  cp -p restraint_parabetarmsd.cpp ../
+  cp -p restraint_mindist.cpp ../
+  cp -p restraint_helix.cpp ../
+  cp -p restraint_hbonds.cpp ../
+  cp -p restraint_energy.cpp ../
+  cp -p restraint_elstpot.cpp ../
+  cp -p restraint_dist.cpp ../
+  cp -p restraint_dipole.cpp ../
+  cp -p restraint_dihcor.cpp ../
+  cp -p restraint_coord.cpp ../
+  cp -p restraint_cmap.cpp ../
+  cp -p restraint_antibetarmsd.cpp ../
+  cp -p restraint_angle.cpp ../
+  cp -p restraint_alpharmsd.cpp ../
+  cp -p restraint_alfabeta.cpp ../
+  cp -p restraint.cpp ../
+  cp -p read_restraint.cpp ../
+  cp -p ptmetad.cpp ../
+  cp -p metadyn.cpp ../
+  cp -p hills.cpp ../
+  cp -p fix_plumed.cpp ../
+  cp -p biasexchange.cpp ../
 
 elif (test $1 = 0) then
 
   rm ../style_user_plumed.h
-  touch ../style_user_plumed.h
-
-  rm ../fix_plumed.cpp
-
+  rm ../metadyn.h
   rm ../fix_plumed.h
+  rm ../testderivatives.cpp
+  rm ../restraint_zpath.cpp
+  rm ../restraint_waterbridge.cpp
+  rm ../restraint_torsion.cpp
+  rm ../restraint_spath.cpp
+  rm ../restraint_rmsdtor.cpp
+  rm ../restraint_rgyr.cpp
+  rm ../restraint_puckering.cpp
+  rm ../restraint_position.cpp
+  rm ../restraint_parabetarmsd.cpp
+  rm ../restraint_mindist.cpp
+  rm ../restraint_helix.cpp
+  rm ../restraint_hbonds.cpp
+  rm ../restraint_energy.cpp
+  rm ../restraint_elstpot.cpp
+  rm ../restraint_dist.cpp
+  rm ../restraint_dipole.cpp
+  rm ../restraint_dihcor.cpp
+  rm ../restraint_coord.cpp
+  rm ../restraint_cmap.cpp
+  rm ../restraint_antibetarmsd.cpp
+  rm ../restraint_angle.cpp
+  rm ../restraint_alpharmsd.cpp
+  rm ../restraint_alfabeta.cpp
+  rm ../restraint.cpp
+  rm ../read_restraint.cpp
+  rm ../ptmetad.cpp
+  rm ../metadyn.cpp
+  rm ../hills.cpp
+  rm ../fix_plumed.cpp
+  rm ../biasexchange.cpp
 
 fi
 EOF
-cat > ./USER-PLUMED/Install.csh << \EOF
+cat > ./Install.csh << \EOF
 # Install/unInstall package classes in LAMMPS
 
 if ($1 == 1) then
 
-  cp -p style_user_plumed.h ..
-
-  cp -p fix_plumed.cpp ..
-
-  cp -p fix_plumed.h ..
+  cp -p style_user_plumed.h ../
+  cp -p metadyn.h ../
+  cp -p fix_plumed.h ../
+  cp -p testderivatives.cpp ../
+  cp -p restraint_zpath.cpp ../
+  cp -p restraint_waterbridge.cpp ../
+  cp -p restraint_torsion.cpp ../
+  cp -p restraint_spath.cpp ../
+  cp -p restraint_rmsdtor.cpp ../
+  cp -p restraint_rgyr.cpp ../
+  cp -p restraint_puckering.cpp ../
+  cp -p restraint_position.cpp ../
+  cp -p restraint_parabetarmsd.cpp ../
+  cp -p restraint_mindist.cpp ../
+  cp -p restraint_helix.cpp ../
+  cp -p restraint_hbonds.cpp ../
+  cp -p restraint_energy.cpp ../
+  cp -p restraint_elstpot.cpp ../
+  cp -p restraint_dist.cpp ../
+  cp -p restraint_dipole.cpp ../
+  cp -p restraint_dihcor.cpp ../
+  cp -p restraint_coord.cpp ../
+  cp -p restraint_cmap.cpp ../
+  cp -p restraint_antibetarmsd.cpp ../
+  cp -p restraint_angle.cpp ../
+  cp -p restraint_alpharmsd.cpp ../
+  cp -p restraint_alfabeta.cpp ../
+  cp -p restraint.cpp ../
+  cp -p read_restraint.cpp ../
+  cp -p ptmetad.cpp ../
+  cp -p metadyn.cpp ../
+  cp -p hills.cpp ../
+  cp -p fix_plumed.cpp ../
+  cp -p biasexchange.cpp ../
 
 else if ($1 == 0) then
 
   rm ../style_user_plumed.h
-  touch ../style_user_plumed.h
-
-  rm ../fix_plumed.cpp
-
+  rm ../metadyn.h
   rm ../fix_plumed.h
+  rm ../testderivatives.cpp
+  rm ../restraint_zpath.cpp
+  rm ../restraint_waterbridge.cpp
+  rm ../restraint_torsion.cpp
+  rm ../restraint_spath.cpp
+  rm ../restraint_rmsdtor.cpp
+  rm ../restraint_rgyr.cpp
+  rm ../restraint_puckering.cpp
+  rm ../restraint_position.cpp
+  rm ../restraint_parabetarmsd.cpp
+  rm ../restraint_mindist.cpp
+  rm ../restraint_helix.cpp
+  rm ../restraint_hbonds.cpp
+  rm ../restraint_energy.cpp
+  rm ../restraint_elstpot.cpp
+  rm ../restraint_dist.cpp
+  rm ../restraint_dipole.cpp
+  rm ../restraint_dihcor.cpp
+  rm ../restraint_coord.cpp
+  rm ../restraint_cmap.cpp
+  rm ../restraint_antibetarmsd.cpp
+  rm ../restraint_angle.cpp
+  rm ../restraint_alpharmsd.cpp
+  rm ../restraint_alfabeta.cpp
+  rm ../restraint.cpp
+  rm ../read_restraint.cpp
+  rm ../ptmetad.cpp
+  rm ../metadyn.cpp
+  rm ../hills.cpp
+  rm ../fix_plumed.cpp
+  rm ../biasexchange.cpp
 
 endif
 EOF
-cat >./USER-PLUMED/fix_plumed.cpp << \EOF
+cat >./fix_plumed.cpp << \EOF
 /*
 *******************************************************************************
 *                                                                             *
 *                                PLUMED                                       *
 *   A Portable Plugin for Free Energy Calculations with Molecular Dynamics    *
-*                              VERSION 1.2                                    *
+*                              VERSION 1.3                                    *
 *                                                                             *
 *******************************************************************************
 *
 *  
-*  Copyright (c) 2010 The PLUMED team.
+*  Copyright (c) 2008-2011 The PLUMED team.
 *  See http://www.plumed-code.org for more information. 
 *
 *  This file is part of PLUMED.
@@ -476,18 +585,18 @@ void FixPlumed::min_post_force(int vflag)
   post_force(vflag);
 }
 EOF
-cat >./USER-PLUMED/fix_plumed.h  << \EOF
+cat >./fix_plumed.h  << \EOF
 /*
 *******************************************************************************
 *                                                                             *
 *                                PLUMED                                       *
 *   A Portable Plugin for Free Energy Calculations with Molecular Dynamics    *
-*                              VERSION 1.3                                    *
+*                              VERSION 1.2                                    *
 *                                                                             *
 *******************************************************************************
 *
 *  
-*  Copyright (c) 2008-2011 The PLUMED team.
+*  Copyright (c) 2010 The PLUMED team.
 *  See http://www.plumed-code.org for more information. 
 *
 *  This file is part of PLUMED.
@@ -556,7 +665,7 @@ class FixPlumed : public Fix {
 #endif
 EOF
 
-cat >./USER-PLUMED/style_user_plumed.h << \EOF
+cat >./style_user_plumed.h << \EOF
 #ifdef FixInclude
 #include "fix_plumed.h"
 #endif
@@ -566,23 +675,17 @@ FixStyle(plumed,FixPlumed)
 #endif
 EOF
 
+cd ../
+
 #(this substitutes old "patch" command in diff directory)
 mv Makefile Makefile.preplumed
-#awk '/user-imd user-smd =/{print $0," user-plumed"}!/user-imd user-smd =/{print}' Makefile.preplumed > Makefile
 sed 's/PACKUSER =/PACKUSER = user-plumed /' Makefile.preplumed > Makefile
-#("make makelist" version 07Nov09 does not work due to sed not accepting long strings, here down alternative command)
-awk '/^SRC =/{system("echo SRC = `ls *.cpp`")}
-     /^INC =/{system("echo INC = `ls *.h`")}  
-     !(/^SRC =/||/^INC =/){print}' Makefile.list > l; mv l Makefile.list
-echo '#include "style_user_plumed.h"' >> style_user_packages.h
-sed s/"CCFLAGS \="/"CCFLAGS \=  -DLAMMPS_PLUMED"/ ./MAKE/Makefile.$myarch > l ;
-cp   ./MAKE/Makefile.$myarch  ./MAKE/Makefile.${myarch}.preplumed; 
-mv l ./MAKE/Makefile.$myarch 
+
+for file in ./MAKE/Makefile.* ; do
+  mv "$file" "${file}.preplumed"
+  sed s/"CCFLAGS \="/"CCFLAGS \=  -DLAMMPS_PLUMED"/ ${file}.preplumed > $file
+done
 make yes-user-plumed
-#("make makelist" version 07Nov09 does not work due to sed not accepting long strings, here down alternative command)
-awk '/^SRC =/{system("echo SRC = `ls *.cpp`")}
-     /^INC =/{system("echo INC = `ls *.h`")}  
-     !(/^SRC =/||/^INC =/){print}' Makefile.list > l; mv l Makefile.list
 }
 
 function to_do_before_revert () {
@@ -591,15 +694,8 @@ function to_do_before_revert () {
 }
 
 function to_do_after_revert () {
-  rm -rf USER-PLUMED
   make no-user-plumed
-  #("make makelist" version 07Nov09 does not work due to sed not accepting long strings, here down alternative command)
-  awk '/SRC =/{system("echo SRC = `ls *.cpp`")}
-       /INC =/{system("echo INC = `ls *.h`")}  
-       !/[SRC =][INC =]/{print}' Makefile.list > l; mv l Makefile.list
-  grep -v style_user_plumed style_user_packages.h > l;mv l style_user_packages.h
-  mv Makefile.preplumed Makefile
-  mv  ./MAKE/Makefile.${myarch}.preplumed ./MAKE/Makefile.$myarch 
+  rm -rf USER-PLUMED
 }
 
 #########
